@@ -1,4 +1,4 @@
-#!/usr/bin/python26
+#!/usr/bin/python
 
 """This file contains the classes needed to manage twitcher configs.
 
@@ -115,7 +115,7 @@ class _NamespaceConfig(object):
         'RegisterWatch: timeout must be a number.')
 
     if description is None:
-      description = '%s-%s' % (self._config_file, len(self._configurations) + 1)
+      description = '{0}-{1}'.format(self._config_file, len(self._configurations) + 1)
 
     kwargs = {}
     kwargs['description'] = description
@@ -212,7 +212,7 @@ class ConfigFile(inotify.WatchClass):
       for o in objects:
         o.init()
     except Exception, e:
-      logging.error('Exception processing %s: %s' % (self._filename, e))
+      logging.error('Exception processing %s: %s', self._filename, e)
       return
 
     self._config_objects = objects
