@@ -1,4 +1,4 @@
-#!/usr/bin/python26
+#!/usr/bin/python
 
 """Core functionality for Twitcher.
 
@@ -417,8 +417,7 @@ class TwitcherObject(object):
     for p in self._processes:
       r = p.poll()
       if r is not None:
-        logging.warning('Process "%s" (%s) exited with code %s',
-                        p.desc, p.pid, r)
+        logging.warning('Process "%s" (%s) exited with code %s', p.desc, p.pid, r)
         self._processes.remove(p)
         removed.append(p)
     self._lock.release()
@@ -478,7 +477,7 @@ class TwitcherObject(object):
     Returns:
       Nothing.
     """
-    logging.warning('Executing process: %s' % self._description)
+    logging.warning('Executing process: %s', self._description)
     try:
       p = MinimalSubprocess(self._description, data, timeout=self._timeout)
       p.fork_exec(self._run_func, self._uid, self._gid)
@@ -488,11 +487,9 @@ class TwitcherObject(object):
       if default_ping_fd is not None:
         os.write(default_ping_fd, '\0')
     except UnknownUserError:
-      logging.error('%s: Unable to find user %s', self._description,
-                    self._uid)
+      logging.error('%s: Unable to find user %s', self._description, self._uid)
     except UnknownGroupError:
-      logging.error('%s: Unable to find group %s', self._description,
-                    self._gid)
+      logging.error('%s: Unable to find group %s', self._description, self._gid)
 
   def _post_exec(self):
     """Run once the script has finished executing.
@@ -515,15 +512,14 @@ class TwitcherObject(object):
       elif self._run_mode == QUEUE:
         # Re run the watch that we missed as though we just received it. We do
         # this by passing the arguments back into the mix.
-        logging.debug('Processing queued watches on %s',
-                      self._unhandled_watch[1])
+        logging.debug('Processing queued watches on %s', self._unhandled_watch[1])
         args = self._unhandled_watch
         self._unhandled_watch = None
         self._watch(*args)
       else:
         # We shouldn't ever get here.
         # FIXME(brady):
-        logging.error('_run_mode is invalid in %s' % self)
+        logging.error('_run_mode is invalid in %s', self)
 
   def _watch(self, zh, path):
     """Called when a zookeeper node we are watching updates.
@@ -545,8 +541,7 @@ class TwitcherObject(object):
     """
     logging.info('Received watch notification for %s', path)
     if self._processes and self._run_mode != PARALLEL:
-      logging.warning('Postponing processing of "%s" '
-                      '(a script is already running).', self._description)
+      logging.warning('Postponing processing of "%s" (a script is already running).', self._description)
       self._unhandled_watch = (zh, path)
       if self._notify_signal is not None:
         for i in self._processes:
@@ -602,4 +597,4 @@ class TwitcherChildrenObject(TwitcherObject):
     default_zkwrapper.aget_children(self._path, handler=h, watcher=self._watch)
     
   def _exec(self, data):
-      super(TwitcherChildrenObject, self)._exec("\n".join(data))
\ No newline at end of file
+      super(TwitcherChildrenObject, self)._exec("\n".join(data))
